# simple plotting + fitting + simulation + latex

based on https://github.com/APN-Pucky/smpl

Doc: https://apn-pucky.github.io/smpl/index.html

[![PyPI version](https://badge.fury.io/py/smpl.svg)](https://badge.fury.io/py/smpl)
![workflow](https://github.com/APN-Pucky/smpl/actions/workflows/stable.yml/badge.svg)
![downloads](https://img.shields.io/pypi/dm/smpl.svg)
